@@ -1,7 +1,7 @@
 use crate::*;
 
-mod render_base;
-mod render_plots;
+pub mod render_base;
+pub mod render_plots;
 
 #[derive(Copy, Clone)]
 pub struct Canvas {
@@ -102,36 +102,6 @@ impl Canvas {
             num_css_classes,
         }
     }
-
-    pub fn render_plots<
-        XI: IntoIterator,
-        YI: IntoIterator,
-        PF: PlotFmt<X = XI::Item, Y = YI::Item>,
-    >(
-        writer: impl std::fmt::Write,
-        plotter: &mut Plotter<XI, YI, PF>,
-    ) -> std::fmt::Result
-    where
-        XI::Item: PlotNum,
-        YI::Item: PlotNum,
-    {
-        render_plots::render_plots(writer, plotter)
-    }
-
-    pub fn render_base<
-        XI: IntoIterator,
-        YI: IntoIterator,
-        PF: PlotFmt<X = XI::Item, Y = YI::Item>,
-    >(
-        writer: impl std::fmt::Write,
-        plotter: &mut Plotter<XI, YI, PF>,
-    ) -> std::fmt::Result
-    where
-        XI::Item: PlotNum,
-        YI::Item: PlotNum,
-    {
-        render_base::render_base(writer, plotter)
-    }
 }
 
 pub fn line_fill<T: std::fmt::Write>(
